"""YAML Resume Builder Package.

A package to generate PDF resumes from YAML files using LaTeX templates.
"""

from yaml_resume_builder.builder import build_resume

__version__ = "0.1.2"
__all__ = ["build_resume"]
